@@ -1,4 +1,6 @@
-use crate::audio::{spsc::Consumer, SoundInstance};
+use crate::audio::SoundInstance;
+use crate::sync::Consumer;
+use alloc::vec::Vec;
 
 pub struct Mixer {
     receiver: Consumer<SoundInstance>,
