@@ -1,3 +1,4 @@
+use crate::asset::Asset;
 use cgmath::*;
 
 // Re-exports.
@@ -6,7 +7,8 @@ pub use winit::event::VirtualKeyCode as KeyboardButton;
 
 /// An input event. These are represented as an enumeration to preserve
 /// ordering when stored in a vector and read sequentially.
-#[derive(Copy, Clone, Debug)]
+#[derive(Clone, Debug)]
+#[non_exhaustive]
 pub enum Event {
     /// The window has requested it close.
     CloseRequested,
@@ -35,9 +37,10 @@ pub enum Event {
     /// Cursor moved event. Contains the position of the cursor and the delta from its last
     /// position.
     CursorMoved {
-        /// Current cursor position.
+        /// Current cursor position. This is based on the physical size of the window, with (0,0)
+        /// being the bottom left.
         pos: Vector2<f32>,
-        /// Change from last position.
+        /// Change from last position. This is based on the logical size of the window.
         delta: Vector2<f32>,
     },
     /// Cursor left the bounds of the window event.
@@ -54,6 +57,8 @@ pub enum Event {
     /// etc) that happens as the "main body" of your event loop. The value is the time passed since
     /// the last update in seconds.
     Update(f32),
+    /// Event for when as asset has finished reading and is now available for consumption.
+    AssetRead(Asset),
 }
 
 /// A cursor wheel movement. Some mice have left and right scroll options.
